@@ -18,6 +18,9 @@ class Application:
 
     _builtinsettings = '''
     debug: true
+    staticdir:
+        default: index.html
+        fallback: index.html
     '''
 
     #: Instance of :class:`pymlconf.Root` as the global configuration instance.
@@ -235,7 +238,8 @@ class Application:
         """
         return self.route(pattern, **kw)(static.file(filename))
 
-    def staticdirectory(self, pattern, directory, **kw):
+    def staticdirectory(self, pattern, directory, default=None, fallback=None,
+                        **kw):
         """Register a directory with a regular expression pattern.
 
         So the files inside the directory are accessible by their names:
@@ -254,8 +258,27 @@ class Application:
 
            :ref:`cookbook-static`
 
+        :param pattern: Regular expression to match the requests.
+        :param directory: Static files are here.
+        :param default: if None, the ``app.settings.staticdir.default``
+                        (which default is ``index.html``) will be used as the
+                        default document.
+        :param fallback: if ``True``, the ``app.settings.staticdir.fallback``
+                        (which default is ``index.html``) will be used as the
+                        fallback document if the requested resource was not
+                        found. if ``str``, the value will be used instead of
+                        ``app.settings.staticdir.fallback``.
+
+        .. versionadded:: 2.13
+
+           The *default* and *fallback* keyword arguments.
+
         """
-        return self.route(f'{pattern}(.*)', **kw)(static.directory(directory))
+        return self.route(f'{pattern}(.*)', **kw)(static.directory(
+            directory,
+            default,
+            fallback
+        ))
 
     def climain(self, argv=None):
         """Provide a callable to call as the CLI entry point.
